%define	major	1
%define libname	%mklibname user %{major}
%define develname %mklibname user -d
# we don't want to provide private python extension libs
%define _exclude_files_from_autoprov %{python2_sitearch}/.*\\.so\\|%{python3_sitearch}/.*\\.so
# Python3 will be supported in 0.62 Fedora have it
%define with_python3 1

%define _disable_ld_no_undefined 1

Summary:	A user and group account administration library
Name:		libuser
Version:	0.62
Release:	%mkrel 3
License:	LGPLv2+
Group:		System/Configuration
URL:		https://fedorahosted.org/libuser/
Source0:	https://fedorahosted.org/releases/l/i/libuser/%{name}-%{version}.tar.xz
Patch0:		libuser-0.56.9-fix-str-fmt.patch
Patch2:		libuser-0.56.15-fix_blowfish.patch
BuildRequires:	gettext
BuildRequires:	glib2-devel
BuildRequires:	openldap-devel
BuildRequires:	linuxdoc-tools
BuildRequires:	pam-devel
BuildRequires:	popt-devel
BuildRequires:	python-devel
BuildRequires:	bison
BuildRequires:	openssl
BuildRequires:	locales-en
%if 0%{?with_python3}
BuildRequires:	 python3-devel
%endif # if with_python3
Requires:	coreutils
Requires(pre):	coreutils

%description
The libuser library implements a standardized interface for manipulating
and administering user and group accounts.  The library uses pluggable
back-ends to interface to its data sources.

Sample applications modeled after those included with the shadow password
suite are included.

%package python
Group:		Development/Python
Summary:	Library bindings for python
BuildRequires:	python
Requires:	%{libname} = %{version}-%{release}

%description python
This package contains the python library for python applications that 
use libuser.

%if 0%{?with_python3}
%package python3
Group:		Development/Python
Summary:	Library bindings for python3
Requires:	%{libname} = %{version}-%{release}

%description python3
This package contains the python3 library for python3 applications that 
use libuser.
%endif # if with_python3

%package ldap
Group:		System/Libraries
Summary:	Libuser ldap library
Requires:	%{libname} = %{version}-%{release}

%description ldap
This package contains the libuser ldap library.

%package -n %{libname}
Group:		System/Libraries
Summary:	The actual libraries for libuser
Requires:	%{name} = %{version}-%{release}

%description -n	%{libname}
This is the actual library for the libuser library.

%package -n %{develname}
Group:		Development/Libraries
Summary:	Files needed for developing applications which use libuser
Requires:	%{libname} = %{version}-%{release}
Provides:	%{name}-devel = %{version}-%{release}
Obsoletes:	%mklibname -d user 1

%description -n	%{develname}
The libuser-devel package contains header files, static libraries, and other
files useful for developing applications with libuser.

%prep
%setup -q
%patch0 -p0
%patch2 -p0
%if 0%{?with_python3}
cp -a . %{py3dir}
%endif # if with_python3

%build
export CFLAGS="%{optflags} -fPIC -DG_DISABLE_ASSERT -I/usr/include/sasl -DLDAP_DEPRECATED"
%configure2_5x \
	--with-ldap \
	--with-python \
	--with-popt \
	--without-sasl \
	--disable-rpath \
	--without-selinux \
	--enable-gtk-doc=no
%make

%if 0%{?with_python3}
pushd %{py3dir}
%configure2_5x \
	--with-ldap \
	--with-python \
	--with-popt \
	--without-sasl \
	--disable-rpath \
	--without-selinux \
	--enable-gtk-doc=no \
	PYTHON=%{__python3}
%make
popd
%endif # if with_python3

%install
%if 0%{?with_python3}
pushd %{py3dir}
%makeinstall_std
popd
%endif # if with_python3

%makeinstall_std

%find_lang %{name}

# Remove unpackaged files
rm -rf  %{buildroot}/usr/share/man/man3/userquota.3 \
        %{buildroot}%{python2_sitearch}/*a \
        %{buildroot}%{_libdir}/%{name}/*.la \
	%{buildroot}%{_libdir}/*.la

%if 0%{?with_python3}
rm -rf  %{buildroot}%{python3_sitearch}/*a
%endif # if with_python3

LD_LIBRARY_PATH=%{buildroot}%{_libdir}:${LD_LIBRARY_PATH}
export LD_LIBRARY_PATH

# Verify that all python modules load, just in case.
pushd %{buildroot}%{python2_sitearch}/
%{__python2} -c "import libuser"
popd

%if 0%{?with_python3}
pushd %{buildroot}%{python3_sitearch}/
# The Python 3 module only supports UTF-8
LC_ALL=en_US.UTF-8 \
%{__python3} -c "import libuser"
popd
%endif # if with_python3

%triggerin -n %{libname} -- %{libname} <= 0.62-1
rm -f /etc/shadow.lock

%files -f %{name}.lang
%doc AUTHORS NEWS README TODO docs/*.txt python/modules.txt
%config(noreplace) %{_sysconfdir}/libuser.conf
%{_bindir}/*
%{_sbindir}/*
%dir %{_libdir}/%{name}/
%{_libdir}/%{name}/libuser_files.so
%{_libdir}/%{name}/libuser_shadow.so
%_mandir/man5/*
%{_mandir}/man1/*

%files -n %{libname}
%{_libdir}/libuser.so.%{major}*

%files python
%{python2_sitearch}/*.so

%if 0%{?with_python3}
%files python3
%{python3_sitearch}/*.so
%endif # if with_python3

%files ldap
%{_libdir}/%{name}/libuser_ldap.so

%files -n %{develname}
%{_includedir}/libuser
%{_libdir}/*.so
%{_libdir}/pkgconfig/*
%{_datadir}/gtk-doc/html/*


%changelog
* Sun Sep 13 2020 tex - 0.62-3pclos2020
- rebuild against updates

* Sun Aug 25 2019 tex - 0.62-2pclos2019
- rebuild against updates

* Thu Sep 14 2017 bb2 <bb2> 0.62-1pclos2017
- new version

* Fri Jul 07 2017 bb2 <bb2> 0.60-2pclos2017
- rebuild

* Thu Jan 30 2014 bb <bb> 0.60-1pclos2014
- update

* Thu Aug 15 2013 billybot <billybot> 0.57.2-3pclos2013
- update python 2.7
